import { getTranslations } from "next-intl/server";

import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import { fetchUser } from "@/components/sections/auth/actions";
import AccountInformation from "@/components/sections/user-account/account-informtion";
import PrivacyTable from "@/components/sections/user-account/privacy-table";
import UserAccountHeader from "@/components/sections/user-account/user-account-header";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { LocaleParams } from "@/types/params";
import { HydrationBoundary, dehydrate } from "@tanstack/react-query";
async function UserAccountSettings({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const t = await getTranslations("UserAccount");

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/user-account",
			label: {
				en: "User Account",
				ar: "حساب المستخدم",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["userInfo"], queryFn: fetchUser }),
	]);


	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="block">
				<Header />
				<PageBreadcrump
					locale={locale}
					subtitle={{
						en: "Bin Taleb Company",
						ar: "شركة بن طالب",
					}}
					title={{
						en: "User Account",
						ar: "حساب المستخدم",
					}}
					breadcrumbItems={breadcrumbItems}
				/>
				<div className="px-2 sm:px-2 md:px-4 lg:px-4 xl:px-24">
					<div className="relative mx-2 mb-3 mt-6 max-w-10xl overflow-hidden rounded-lg p-4 shadow-lg md:mx-auto md:mb-8 md:mt-12 md:p-8">
						<UserAccountHeader />
						<AccountInformation />
						<div className="absolute left-0 top-0 z-0 h-16 w-full bg-gradient-blue md:h-24" />
						<PrivacyTable />
					</div>
				</div>
				<Footer />
			</main>
		</HydrationBoundary>
	);
}

export default UserAccountSettings;
